@@ -7,7 +7,7 @@ from certsGenerator.builder import createCerts
 
 class CertsGenerator():
     def __init__(self, pathToConf:str):
-        self.CONF_FILE = "example/conf.json"
+        self.CONF_FILE = pathToConf
     
     def run(self):
         generalConf = loadConf(self.CONF_FILE)
@@ -20,7 +20,7 @@ class CertsGenerator():
             )
 
 @click.command()
-@click.option('--conf', default="example/conf.json",help="Certs configuration file")
+@click.option('--conf', default="data/conf.json",help="Certs configuration file")
 def cli(conf):
     CertsGenerator(pathToConf=conf).run()
 
